@@ -8,32 +8,9 @@ use File::Copy qw(copy);
 use parent 'Module::Build';
 use Ado::Build qw(
   process_etc_files process_public_files
-  process_templates_files
+  process_templates_files create_build_script
   ACTION_perltidy ACTION_submit);
 
-sub create_build_script {
-    my $self = shift;
-    $ENV{ADO_HOME} ||= $self->install_base;
-    if (!$ENV{ADO_HOME} || !-d catdir($ENV{ADO_HOME}, 'lib')) {
-        say <<"MSG";
-       Ado was not found!
-       Please first install Ado!"
-       Do not forget to set \$ADO_HOME environment variable
-       so Ado plugins can easily find it!
-MSG
-        return;
-    }
-    $self->install_base($ENV{ADO_HOME});
-    $self->install_path(arch => catdir($self->install_base, 'lib'));
-    for my $be (qw(lib etc public log templates)) {
-        next unless -d $be;
-        $self->add_build_element($be);
-        $self->install_path($be => catdir($self->install_base, $be));
-    }
-    $self->SUPER::create_build_script();
-    return;
-}
-
 
 1;
 
@@ -48,8 +25,8 @@ Ado::BuildPlugin - Custom routines for Ado::Plugin::* installation
 
 =head1 SYNOPSIS
 
-    #Ado must be already installed in $ENV{ADO_HOME} 
-    use lib("$ENV{ADO_HOME}/lib");
+    #Ado must be already installed  and 
+    #Ado::BuildPlugin should be somewhere in @INC
     use Ado::BuildPlugin;
     my $builder = Ado::BuildPlugin->new(..);
     $builder->create_build_script();
@@ -60,28 +37,22 @@ This is a subclass of L<Module::Build>.
 We use L<Module::Build::API> to add custom functionality 
 so we can install Ado  and its plugins in a location chosen by the user.
 To use this module for installing your plugins
-$ENV{ADO_HOME} must be available and Ado installed there.
+Build.PL should some how find it in @INC (may be via C<$ENV{PERL5LIB}>).
 
 This module and L<Ado::Build> exist because of the additional install paths
 that we use beside C<lib> and C<bin>. These modules also can serve as examples 
 for your own builders if you have some custom things to do during 
-build, test, install and even if you need to add a new C<ACTION_*> to your setup.
+build, test, install and even if you need to add a new C<ACTION_*> 
+to your setup.
 
 
 =head1 METHODS
 
-Ado::BuildPlugin inherits all methods from L<Module::Build> and implements 
-the following ones. It also imports C<process_etc_files>, C<process_public_files>,
-C<process_templates_files> from L<Ado::Build>.
+Ado::BuildPlugin inherits all methods from L<Module::Build>. 
+It also imports C<create_build_script>, C<process_etc_files>, 
+C<process_public_files>, C<process_templates_files> from L<Ado::Build>.
 
 
-=head2 create_build_script
-
-Creates a C<Build> script for instaling an L<Ado> plugin.
-This method will be called 
-during C<./Build dist> if you set the property C<create_readme> 
-in your C<Build.PL>.
-
 =head1 AUTHOR
 
 Красимир Беров (Krasimir Berov)
